package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysTeacherKpiFillingStuEmergency;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 业绩考核-个人填报-处理学生突发事件Mapper接口
 *
 * @author chc
 * @date 2024-06-12
 */
public interface SysTeacherKpiFillingStuEmergencyMapper extends BaseMapper<SysTeacherKpiFillingStuEmergency> {
    /**
     * 查询业绩考核-个人填报-处理学生突发事件
     *
     * @param id 业绩考核-个人填报-处理学生突发事件主键
     * @return 业绩考核-个人填报-处理学生突发事件
     */
    public SysTeacherKpiFillingStuEmergency selectSysTeacherKpiFillingStuEmergencyById(Long id);

    /**
     * 查询业绩考核-个人填报-处理学生突发事件列表
     *
     * @param sysTeacherKpiFillingStuEmergency 业绩考核-个人填报-处理学生突发事件
     * @return 业绩考核-个人填报-处理学生突发事件集合
     */
    List<SysTeacherKpiFillingStuEmergency> selectSysTeacherKpiFillingStuEmergencyList(SysTeacherKpiFillingStuEmergency sysTeacherKpiFillingStuEmergency);

    /**
     * 查根据辅导员名称、年份 月份 查询
     *
     * @param fdyName 辅导员名称
     * @return 业绩考核-个人填报-处理学生突发事件集合
     */
    List<SysTeacherKpiFillingStuEmergency> selectSysTeacherKpiFillingStuEmergencyByFdyName(@Param("fdyName") String fdyName, @Param("fillingYear") String fillingYear, @Param("fillingMonth") String fillingMonth, @Param("classType") String classType);


    /**
     * 新增业绩考核-个人填报-处理学生突发事件
     *
     * @param sysTeacherKpiFillingStuEmergency 业绩考核-个人填报-处理学生突发事件
     * @return 结果
     */
    int insertSysTeacherKpiFillingStuEmergency(SysTeacherKpiFillingStuEmergency sysTeacherKpiFillingStuEmergency);

    /**
     * 修改业绩考核-个人填报-处理学生突发事件
     *
     * @param sysTeacherKpiFillingStuEmergency 业绩考核-个人填报-处理学生突发事件
     * @return 结果
     */
    int updateSysTeacherKpiFillingStuEmergency(SysTeacherKpiFillingStuEmergency sysTeacherKpiFillingStuEmergency);

    /**
     * 删除业绩考核-个人填报-处理学生突发事件
     *
     * @param id 业绩考核-个人填报-处理学生突发事件主键
     * @return 结果
     */
    int deleteSysTeacherKpiFillingStuEmergencyById(Long id);

    /**
     * 批量删除业绩考核-个人填报-处理学生突发事件
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysTeacherKpiFillingStuEmergencyByIds(Long[] ids);
}
