package com.srs.web.controller.teacher;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.annotation.RepeatSubmit;
import com.srs.teacher.domain.SysTeacherKpiFillingStuMgt;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.teacher.domain.SysTeacherKpiFillingStuEmergency;
import com.srs.teacher.service.ISysTeacherKpiFillingStuEmergencyService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 业绩考核-个人填报-处理学生突发事件Controller
 *
 * @author chc
 * @date 2024-06-12
 */
@RestController
@RequestMapping("/teacher/kpiFillingStuEmergency")
@Api(value = "业绩考核-个人填报-处理学生突发事件管理", tags = "业绩考核-个人填报-处理学生突发事件管理")
public class SysTeacherKpiFillingStuEmergencyController extends BaseController {
    @Autowired
    private ISysTeacherKpiFillingStuEmergencyService sysTeacherKpiFillingStuEmergencyService;

    /**
     * 查询业绩考核-个人填报-处理学生突发事件列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingStuEmergency:list')")
    @GetMapping("/list")
    @ApiOperation("查询业绩考核-个人填报-处理学生突发事件列表")
    public TableDataInfo list(SysTeacherKpiFillingStuEmergency sysTeacherKpiFillingStuEmergency) {
        startPage();
        List<SysTeacherKpiFillingStuEmergency> list = sysTeacherKpiFillingStuEmergencyService.selectSysTeacherKpiFillingStuEmergencyList(sysTeacherKpiFillingStuEmergency);
        return getDataTable(list);
    }

    /**
     * 根据辅导员名称、年份 月份 查询详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingStuEmergency:list')")
    @GetMapping("/getByFdyNameAndYearAndMonth")
    @ApiOperation("根据名称年月查询业绩考核-个人填报-处理学生突发事件列表")
    public TableDataInfo getByFdyNameAndYearAndMonth(@RequestParam String fdyName, @RequestParam String fillingYear, @RequestParam String fillingMonth, @RequestParam(required = false) String classType) {
        startPage();
        List<SysTeacherKpiFillingStuEmergency> list = sysTeacherKpiFillingStuEmergencyService.selectSysTeacherKpiFillingStuEmergencyByFdyName(fdyName, fillingYear, fillingMonth, classType);
        return getDataTable(list);
    }

    /**
     * 导出业绩考核-个人填报-处理学生突发事件列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingStuEmergency:export')")
    @Log(title = "业绩考核-个人填报-处理学生突发事件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出业绩考核-个人填报-处理学生突发事件列表")
    public void export(HttpServletResponse response, SysTeacherKpiFillingStuEmergency sysTeacherKpiFillingStuEmergency) {
        List<SysTeacherKpiFillingStuEmergency> list = sysTeacherKpiFillingStuEmergencyService.selectSysTeacherKpiFillingStuEmergencyList(sysTeacherKpiFillingStuEmergency);
        ExcelUtil<SysTeacherKpiFillingStuEmergency> util = new ExcelUtil<SysTeacherKpiFillingStuEmergency>(SysTeacherKpiFillingStuEmergency.class);
        util.exportExcel(response, list, "业绩考核-个人填报-处理学生突发事件数据");
    }

    /**
     * 获取业绩考核-个人填报-处理学生突发事件详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingStuEmergency:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取业绩考核-个人填报-处理学生突发事件详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysTeacherKpiFillingStuEmergencyService.selectSysTeacherKpiFillingStuEmergencyById(id));
    }

    /**
     * 新增业绩考核-个人填报-处理学生突发事件
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingStuEmergency:add')")
    @Log(title = "业绩考核-个人填报-处理学生突发事件", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增业绩考核-个人填报-处理学生突发事件")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult add(@RequestBody SysTeacherKpiFillingStuEmergency sysTeacherKpiFillingStuEmergency) {
        return toAjax(sysTeacherKpiFillingStuEmergencyService.insertSysTeacherKpiFillingStuEmergency(sysTeacherKpiFillingStuEmergency));
    }

    /**
     * 修改业绩考核-个人填报-处理学生突发事件
     */
    @PreAuthorize("@ss.hasAnyPermi('teacher:kpiFillingStuEmergency:edit,teacher:kpiFillingStuEmergency:add')")
    @Log(title = "业绩考核-个人填报-处理学生突发事件", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改业绩考核-个人填报-处理学生突发事件")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult edit(@RequestBody SysTeacherKpiFillingStuEmergency sysTeacherKpiFillingStuEmergency) {
        return toAjax(sysTeacherKpiFillingStuEmergencyService.updateSysTeacherKpiFillingStuEmergency(sysTeacherKpiFillingStuEmergency));
    }

    /**
     * 删除业绩考核-个人填报-处理学生突发事件
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingStuEmergency:remove')")
    @Log(title = "业绩考核-个人填报-处理学生突发事件", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除业绩考核-个人填报-处理学生突发事件")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysTeacherKpiFillingStuEmergencyService.deleteSysTeacherKpiFillingStuEmergencyByIds(ids));
    }
}
